/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.urlhandlers;

import org.wso2.registry.RegistryException;
import org.wso2.registry.Resource;

import javax.sql.DataSource;

/**
 * Base class for URL handlers. URL handlers are used support virtual resources. JDBC registry
 * allows users to access some none-resource entities in the same way they access normal resources
 * (e.g. comments, tags, ratings). These entities can be accessed by providing a special URL to
 * identify the virtual resource.
 * <p/>
 * For example tags for the resource at path /projects/mybank/design can be accessed by the URL
 * /projects/mybank/design?tags. URL handlers are used to support that behavior. That is, we can
 * register URL handlers to handle each type of virtual resource. Then those URL handlers are
 * responsible for interpreting the special URL and generating the virtual resource referred by that
 * URL.
 */
public abstract class URLHandler {

    protected DataSource dataSource;

    public URLHandler(DataSource dataSource) {
        this.dataSource = dataSource;
    }

    public abstract boolean handleURL(String url, Resource resource) throws RegistryException;
}
