/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.actions;

import org.wso2.registry.ActionConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.UserManagerException;

import javax.servlet.http.HttpServletRequest;

public class RoleAuthorizationAction extends AbstractRegistryAction {

    private String pathToAuthorize;
    private String roleToAuthorize;

    private String actionToAuthorize;
    private String permissionType;

    public String execute(HttpServletRequest request) throws RegistryException {

        setRequest(request);

        SecureRegistry secureRegistry = (SecureRegistry) getRegistry();
        Realm userRealm = secureRegistry.getUserRealm();

        try {
            if (actionToAuthorize.equals("2")) {

                if (permissionType.equals("1")) {
                    userRealm.getAccessControlAdmin().authorizeRole(roleToAuthorize, pathToAuthorize, ActionConstants.GET);
                } else {
                    userRealm.getAccessControlAdmin().denyRole(roleToAuthorize, pathToAuthorize, ActionConstants.GET);
                }
            }

            if (actionToAuthorize.equals("3")) {

                if (permissionType.equals("1")) {
                    userRealm.getAccessControlAdmin().authorizeRole(roleToAuthorize, pathToAuthorize, ActionConstants.PUT);
                } else {
                    userRealm.getAccessControlAdmin().denyRole(roleToAuthorize, pathToAuthorize, ActionConstants.PUT);
                }
            }

            if (actionToAuthorize.equals("4")) {

                if (permissionType.equals("1")) {
                    userRealm.getAccessControlAdmin().authorizeRole(roleToAuthorize, pathToAuthorize, ActionConstants.DELETE);
                } else {
                    userRealm.getAccessControlAdmin().denyRole(roleToAuthorize, pathToAuthorize, ActionConstants.DELETE);
                }
            }
        } catch (UserManagerException e) {
            String msg = "Could not set authorizations. Caused by: " + e.getMessage();
            throw new RegistryException(msg);
        }

        return SUCCESS;
    }


    public String getPathToAuthorize() {
        return pathToAuthorize;
    }

    public void setPathToAuthorize(String pathToAuthorize) {
        this.pathToAuthorize = pathToAuthorize;
    }

    public String getRoleToAuthorize() {
        return roleToAuthorize;
    }

    public void setRoleToAuthorize(String roleToAuthorize) {
        this.roleToAuthorize = roleToAuthorize;
    }

    public String getActionToAuthorize() {
        return actionToAuthorize;
    }

    public void setActionToAuthorize(String actionToAuthorize) {
        this.actionToAuthorize = actionToAuthorize;
    }

    public String getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(String permissionType) {
        this.permissionType = permissionType;
    }
}
